import { Tooltip, Typography } from "@mui/material";
import { TypographyProps } from "@mui/material";
import { PropsWithChildren, ReactElement, useState } from "react";

interface propsType {
  componentProps: TypographyProps;
  hoverBorderColor?: string;
  hoverBackgroundColor?: string;
}

/**
 * NerdClickToCopy component
 *
 * @param {propsType} props Component props
 * @returns {ReactElement} NerdClickToCopy
 */
export default function NerdClickToCopy(
  props: PropsWithChildren<propsType>
): ReactElement {
  const { children, componentProps, hoverBorderColor, hoverBackgroundColor } =
    props;
  const CLICK_TO_COPY = "Click to copy";
  const COPIED = "Copied !";
  const [tooltipText, setTooltipText] = useState(CLICK_TO_COPY);

  /**
   * Copy to clipboard
   *
   * @param {MouseEvent<HTMLSpanElement, MouseEvent>} e Click Event
   * @returns {Promise<void>}
   */
  async function copy(
    e: React.MouseEvent<HTMLSpanElement, MouseEvent>
  ): Promise<void> {
    if (!navigator.clipboard) return;
    const value = e.currentTarget.textContent;
    if (value !== null) {
      await navigator.clipboard.writeText(value);
      setTooltipText(COPIED);
    }
  }

  return (
    <Tooltip title={tooltipText}>
      <Typography
        onClick={copy}
        onMouseOver={() => setTooltipText(CLICK_TO_COPY)}
        sx={{
          margin: "1px 4px 1px 4px",
          padding: 0,
          ":hover": {
            backgroundColor: hoverBackgroundColor || "rgba(0, 153, 255, 0.28)",
            border: `1px ${hoverBorderColor || "rgba(0, 153, 255, 1)"} solid`,
            borderRadius: "5px",
            padding: "0px 3px 0px 3px",
            margin: 0,
          },
        }}
        {...componentProps}
      >
        {children}
      </Typography>
    </Tooltip>
  );
}
